@@ -6,7 +6,7 @@
 #
 
 package File::ByLine::Object;
-$File::ByLine::Object::VERSION = '1.181951'; # TRIAL
+$File::ByLine::Object::VERSION = '1.181962'; # TRIAL
 use v5.10;
 
 # ABSTRACT: Internal object used by File::ByLine
@@ -577,8 +577,8 @@ sub _require_parallel {
     require Parallel::WorkUnit
       or die("You must install Parallel::WorkUnit to use the parallel_* methods");
 
-    if ( $Parallel::WorkUnit::VERSION < 1.117 ) {
-        die( "Parallel::WorkUnit version 1.117 or newer required. You have "
+    if ( $Parallel::WorkUnit::VERSION < 2.181850 ) {
+        die( "Parallel::WorkUnit version 2.181850 or newer required. You have "
               . $Parallel::WorkUnit::Version );
     }
 
@@ -633,7 +633,7 @@ sub _is_number {
             [0-9]+          # ASCII digit
             (?: \. 0+)?     # Optional .0 or .000 or .00000 etc
             \z              # End of string
-        /sxx;
+        /sx;
 }
 
 # Returns an extended info object
@@ -707,7 +707,7 @@ File::ByLine::Object - Internal object used by File::ByLine
 
 =head1 VERSION
 
-version 1.181951
+version 1.181962
 
 =head1 SEE File::ByLine
 
